#' @title Measurement of Biodiversity in R 
#' 
#' @description  The primary aim of this package is to provide ecologist's tools
#'   to examine changes in biodiversity across spatial scales.  Additionally, the
#'   package provides a method to examine how a factor mediates species richness
#'   via its effects on different aspects of community structure: total
#'   abundance, species commonness, and spatial aggregation of conspecifics.
#' 
#' @name mobr
"_PACKAGE"

